@@ -4,7 +4,7 @@
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
 
-from typing import List, Optional, Tuple
+from typing import List, Optional
 from mitosheet.code_chunks.code_chunk import CodeChunk
 
 
@@ -17,8 +17,8 @@ class NoOpCodeChunk(CodeChunk):
     def get_description_comment(self) -> str:
         return "No comment"
 
-    def get_code(self) -> Tuple[List[str], List[str]]:
-        return [], []
+    def get_code(self) -> List[str]:
+        return []
 
     def combine_right(self, other_code_chunk: CodeChunk) -> Optional[CodeChunk]:
         # The empty code chunk always overwrites itself with the right code chunk
